"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var SourceFileTreeNode_1 = require("./SourceFileTreeNode");
var path = require("path");
var log4js = require("log4js");
var util = require("./util");
var fileUrl = require("file-url");
var log = log4js.getLogger('HtmlReporter');
var DEFAULT_BASE_FOLDER = 'reports/mutation/html';
var HtmlReporter = (function () {
    function HtmlReporter(options) {
        this.options = options;
        this.rootNode = new SourceFileTreeNode_1.default('/');
        log4js.setGlobalLogLevel(options.logLevel || 'info');
    }
    HtmlReporter.prototype.onAllSourceFilesRead = function (files) {
        var _this = this;
        files.forEach(function (f) { return _this.rootNode.addSourceFile(f); });
    };
    HtmlReporter.prototype.onAllMutantsTested = function (results) {
        var _this = this;
        results.forEach(function (r) { return _this.rootNode.addMutantResult(r); });
        this.generateReport();
    };
    HtmlReporter.prototype.generateReport = function () {
        var _this = this;
        this.rootNode.normalizeNames();
        this.mainPromise = this.cleanBaseFolder().then(function () { return _this.writeCommonResources(); }).then(function () {
            _this.writeReport();
        });
    };
    HtmlReporter.prototype.writeBootstrapAndHighlightResources = function () {
        var resourcesDir = path.join(__dirname, '..', 'resources');
        return util.copyFolder(resourcesDir, this.baseDir);
    };
    HtmlReporter.prototype.writeStrykerResources = function () {
        var resourcesDir = path.join(__dirname, 'resources', 'stryker');
        return util.copyFolder(resourcesDir, this.baseDir);
    };
    HtmlReporter.prototype.writeCommonResources = function () {
        return Promise.all([this.writeStrykerResources(), this.writeBootstrapAndHighlightResources()]);
    };
    HtmlReporter.prototype.writeReport = function () {
        this.rootNode.calculateModel('');
        this.rootNode.writeReportNodeRecursive(this.baseDir);
        log.info("Your report can be found at: " + fileUrl(path.resolve(this.baseDir, 'index.html')));
    };
    Object.defineProperty(HtmlReporter.prototype, "baseDir", {
        get: function () {
            if (!this._baseDir) {
                if (this.options['htmlReporter'] && this.options['htmlReporter']['baseDir']) {
                    this._baseDir = this.options['htmlReporter']['baseDir'];
                    log.debug("Using configured output folder " + this._baseDir);
                }
                else {
                    log.debug("No base folder configuration found (using configuration: htmlReporter: { baseDir: 'output/folder' }), using default " + DEFAULT_BASE_FOLDER);
                    this._baseDir = DEFAULT_BASE_FOLDER;
                }
            }
            return this._baseDir;
        },
        enumerable: true,
        configurable: true
    });
    HtmlReporter.prototype.cleanBaseFolder = function () {
        var _this = this;
        return util.deleteDir(this.baseDir).then(function () { return util.mkdirRecursive(_this.baseDir); });
    };
    HtmlReporter.prototype.wrapUp = function () {
        return this.mainPromise;
    };
    return HtmlReporter;
}());
exports.default = HtmlReporter;
//# sourceMappingURL=HtmlReporter.js.map